package com.example.recyclerviewdemo2;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.os.Handler;
import android.support.annotation.Nullable;
import android.support.v7.widget.RecyclerView;
import android.util.Log;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import com.cneeds.notouch.NoTouchConstant;
import com.cneeds.notouch.NoTouchListener;
import com.cneeds.notouch.NoTouchManager;
import com.cneeds.notouch.NoTouchParam;
import com.cneeds.notouch.bean.ActivityOperationBean;
import com.cneeds.notouch.bean.CoordinateBean;
import com.cneeds.rvhelpers.CenterGridLayoutManager;
import com.cneeds.rvhelpers.helpers.KeyEventHelper;
import com.cneeds.rvhelpers.adapter.GridRecyclerAdapter;
import com.cneeds.rvhelpers.decoration.PinnedHeaderItemDecoration;
import com.cneeds.rvhelpers.entity.ContentBean;
import com.cneeds.rvhelpers.entity.HeaderBean;
import com.cneeds.rvhelpers.helpers.SortDataHelper;

import java.util.ArrayList;
import java.util.List;


public class GridRecyclerActivity extends Activity implements NoTouchListener {

    private RecyclerView mRvGrid;
    private static final String TAG = "GridRecyclerActivity";
    private CenterGridLayoutManager mLayoutManager;
    private GridRecyclerAdapter<Object> mAdapter;
    private ImageView mIvDelete;
    private TextView mTvSelectAll;
    private TextView mTvCancel;
    private TextView mTvEdit;
    private TextView mTvTitle;
    private static final int SPAN_COUNT = 3;
    private List mDataList;

    public static void startUp(Context context) {
        context.startActivity(new Intent(context, GridRecyclerActivity.class));
    }

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_grid_recycler);
        mRvGrid = (RecyclerView) findViewById(R.id.recycler_grid);
        NoTouchManager.getInstance().init(this);
//        initAdapter(GridRecyclerActivity.this, mRvGrid, obtainData());
        mDataList = obtainData2();
        initAdapter(GridRecyclerActivity.this, mRvGrid, SortDataHelper.sortData(mDataList));
        initBarView();
//        handler.postDelayed(runnable, 1000);
    }

    private void initBarView() {
        mIvDelete = (ImageView) findViewById(R.id.iv_delete);
        mIvDelete.setVisibility(View.GONE);
        mTvSelectAll = (TextView) findViewById(R.id.tv_select_all);
        mTvSelectAll.setVisibility(View.GONE);
        mTvCancel = (TextView) findViewById(R.id.tv_cancel);
        mTvCancel.setVisibility(View.GONE);
        mTvEdit = (TextView) findViewById(R.id.tv_edit);
        mTvTitle = (TextView) findViewById(R.id.tv_title);

        mTvEdit.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                mAdapter.setEditMode(true);
                mIvDelete.setVisibility(View.VISIBLE);
                mTvSelectAll.setVisibility(View.VISIBLE);
                mTvCancel.setVisibility(View.VISIBLE);
                mTvEdit.setVisibility(View.GONE);
                mTvTitle.setVisibility(View.INVISIBLE);
            }
        });


        mTvCancel.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                mAdapter.setEditMode(false);
                mIvDelete.setVisibility(View.GONE);
                mTvSelectAll.setVisibility(View.GONE);
                mTvCancel.setVisibility(View.GONE);
                mTvEdit.setVisibility(View.VISIBLE);
                mTvTitle.setVisibility(View.VISIBLE);
            }
        });


        mTvSelectAll.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if ("全不选".equals(mTvSelectAll.getText())) {
                    mAdapter.clearAllSelection();
                    mTvSelectAll.setText("全选");
                } else {
                    mAdapter.selectAll();
                    mTvSelectAll.setText("全不选");
                }
            }
        });


        mIvDelete.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //注意，如果是用SortDataHelper类，记得把原始的DataList里面的值也删掉,如下
                mDataList.removeAll(mAdapter.getSelectedItems());
                mAdapter.deleteSelected();

            }
        });


        mAdapter.setOnSelectListener(new GridRecyclerAdapter.OnSelectListener() {
            @Override
            public void onSelect(View v, int position, boolean isChecked, List allSelectedItems, int contentItemCount) {
                if (mTvSelectAll != null && mTvSelectAll.getVisibility() == View.VISIBLE) {
                    if (allSelectedItems != null && allSelectedItems.size() != contentItemCount) {
                        if ("全不选".equals(mTvSelectAll.getText())) {
                            mTvSelectAll.setText("全选");
                        }
                    } else {
                        if ("全选".equals(mTvSelectAll.getText())) {
                            mTvSelectAll.setText("全不选");
                        }
                    }
                }
            }
        });

        mAdapter.setOnItemClickListener(new GridRecyclerAdapter.OnItemClickListener() {
            @Override
            public void onItemClick(View v, int position) {
                Toast.makeText(v.getContext(), "点击了" + position, Toast.LENGTH_SHORT).show();
            }
        });
    }

    private void initAdapter(Context context, RecyclerView recyclerView, final List<Object> dataList) {

        mAdapter = new GridRecyclerAdapter<>(dataList, SPAN_COUNT);
        mLayoutManager = new CenterGridLayoutManager(context, SPAN_COUNT, mAdapter);
        recyclerView.setLayoutManager(mLayoutManager);
        recyclerView.setAdapter(mAdapter);
        recyclerView.addItemDecoration(new PinnedHeaderItemDecoration());
        // 解决notifyItemChanged闪烁问题：参考：https://blog.csdn.net/u014537423/article/details/52777978
        recyclerView.getItemAnimator().setSupportsChangeAnimations(false);
    }

    @Override
    public ActivityOperationBean onSelectedChange(CoordinateBean coordinateBean) {
        ActivityOperationBean activityOperationBean = new ActivityOperationBean();
        int x = coordinateBean.getX();

        if (coordinateBean.getY() == 0 && !outOfFirstBound(coordinateBean)) {
            handleKeyEvent(coordinateBean, activityOperationBean);
            if (activityOperationBean.getOperationResult() == NoTouchConstant.OperationResult.SUCCESS) {
                if (mAdapter.getCurrentHighLightPosition() != GridRecyclerAdapter.NONE_SELECT) {
                    mAdapter.setCurrentHighLight(GridRecyclerAdapter.NONE_SELECT);
                }
            }
        } else {
            clearHighlight();
            mCurrentHighlightView = null;
            if (mAdapter != null) {
                KeyEventHelper.PositionBean positionBean = mAdapter.moveToNext(coordinateBean.getX(), coordinateBean.getY() - 1);
                coordinateBean.setY(positionBean.getY() + 1);
                coordinateBean.setX(positionBean.getX());
                int adapterPosition = positionBean.getAdapterPosition();
                if (adapterPosition >= 0) {
                    mRvGrid.smoothScrollToPosition(adapterPosition);
                    activityOperationBean.setOperationResult(NoTouchConstant.OperationResult.SUCCESS);
                } else {
                    activityOperationBean.setOperationResult(NoTouchConstant.OperationResult.FAIL);
                }
            }
        }
        return activityOperationBean;
    }


    @Override
    public ActivityOperationBean onSelectedEnter(CoordinateBean coordinateBean) {
        ActivityOperationBean activityOperationBean = new ActivityOperationBean();
        activityOperationBean.setOperationResult(NoTouchConstant.OperationResult.SUCCESS);
        View view = mAdapter.getHighLightView();
        if (view != null) {
            view.callOnClick();
        }
        if (mCurrentHighlightView != null) {
            mCurrentHighlightView.callOnClick();
            handleKeyEvent(coordinateBean, activityOperationBean);
        }

        return activityOperationBean;
    }

    @Override
    public ActivityOperationBean onSelectNone() {
        Log.d(TAG, "onSelectNone");
        ActivityOperationBean activityOperationBean = new ActivityOperationBean();
        activityOperationBean.setOperationResult(NoTouchConstant.OperationResult.SUCCESS);
        if (mAdapter != null && mAdapter.getCurrentHighLightPosition() != GridRecyclerAdapter.NONE_SELECT) {
            mAdapter.setCurrentHighLight(GridRecyclerAdapter.NONE_SELECT);
        } else {
            // 清除顶部按钮的选中状态
            clearHighlight();
        }
        return activityOperationBean;
    }

    @Override
    public boolean dispatchTouchEvent(MotionEvent ev) {
        return super.dispatchTouchEvent(ev);
    }

    @Override
    public boolean dispatchKeyEvent(KeyEvent event) {
        Log.d(TAG, "dispatchKeyEvent Action : " + event.getAction());

        if (event.getAction() == KeyEvent.ACTION_UP) {
            if (NoTouchManager.getInstance().checkUseKeyCode(event.getKeyCode())) {
                NoTouchManager.getInstance().onKeyDown(event.getKeyCode(), event);
            }
        }
        int code = event.getKeyCode();
        if (code == KeyEvent.KEYCODE_SOFT_RIGHT || code == KeyEvent.KEYCODE_SOFT_LEFT || code == KeyEvent.KEYCODE_DPAD_LEFT
                || code == KeyEvent.KEYCODE_DPAD_UP || code == KeyEvent.KEYCODE_DPAD_RIGHT || code == KeyEvent.KEYCODE_DPAD_DOWN
                || code == KeyEvent.KEYCODE_ENTER) {
            return true;
        }
        return super.dispatchKeyEvent(event);
    }

    private View mCurrentHighlightView;

    private void handleKeyEvent(CoordinateBean coordinateBean, ActivityOperationBean activityOperationBean) {
        if (mTvEdit.getVisibility() == View.VISIBLE && coordinateBean.getX() == 0) {
            setHighlight(mTvEdit);
            activityOperationBean.setOperationResult(NoTouchConstant.OperationResult.SUCCESS);
        } else if (mTvCancel.getVisibility() == View.VISIBLE) {
            switch (coordinateBean.getX()) {
                case 0:
                    setHighlight(mTvCancel);
                    activityOperationBean.setOperationResult(NoTouchConstant.OperationResult.SUCCESS);
                    break;
                case 1:
                    setHighlight(mTvSelectAll);
                    activityOperationBean.setOperationResult(NoTouchConstant.OperationResult.SUCCESS);
                    break;
                case 2:
                    setHighlight(mIvDelete);
                    activityOperationBean.setOperationResult(NoTouchConstant.OperationResult.SUCCESS);
                    break;
                default:
                    activityOperationBean.setOperationResult(NoTouchConstant.OperationResult.FAIL);
                    break;
            }
        } else {
            coordinateBean.setX(0);
            coordinateBean.setY(0);
            setHighlight(mTvEdit);
            activityOperationBean.setOperationResult(NoTouchConstant.OperationResult.SUCCESS);
        }
    }

    private void clearHighlight() {
        if (mTvEdit.getBackground() != null) {
            mTvEdit.setBackground(null);
        }
        if (mTvCancel.getBackground() != null) {
            mTvCancel.setBackground(null);
        }
        if (mTvSelectAll.getBackground() != null) {
            mTvSelectAll.setBackground(null);
        }
        if (mIvDelete.getBackground() != null) {
            mIvDelete.setBackground(null);
        }
    }

    private void setHighlight(View view) {
        clearHighlight();
        Drawable drawable = getResources().getDrawable(R.drawable.rect_solid_border_ff4242_1px);
        view.setBackground(drawable);
        mCurrentHighlightView = view;
    }

    /**
     * 用于处理标题栏光标到了最右边再往右的情况
     *  注意：标题栏有更改的时候，一定要改这里
     * @param coordinateBean
     * @return true: 光标向右动作超出标题栏， false： 光标向右没有超出标题栏
     */
    private boolean outOfFirstBound(CoordinateBean coordinateBean) {
        if (mTvEdit.getVisibility() == View.VISIBLE && coordinateBean.getX() > 0) {
            coordinateBean.setX(0);
            coordinateBean.setY(1);
            return true;
        } else if (mTvCancel.getVisibility() == View.VISIBLE && coordinateBean.getX() > 2) {
            coordinateBean.setX(0);
            coordinateBean.setY(1);
            return true;
        }
        return false;
    }

    @Override
    protected void onResume() {
        super.onResume();
        NoTouchParam.Builder builder = new NoTouchParam.Builder();
        builder.setSpecialFlag(NoTouchConstant.SpecialFlag.SINGLE_LEVEL_FLAG);
        NoTouchManager.getInstance().registerNoTouchListener(this, builder.build());
    }

    @Override
    protected void onPause() {
        super.onPause();
        NoTouchManager.getInstance().unRegisterNoTouchListener(this);
    }

    private List<Object> obtainData() {
        List<Object> list = new ArrayList<>();

        list.add(new HeaderBean("2016年12月01日"));
        list.add(new ContentBean("http://pic.wenwen.soso.com/p/20130907/20130907174128-2028703867.jpg"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=1960816299,803825902&fm=27&gp=0.jpg"));
        list.add(new HeaderBean("2016年12月02日"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=3790810349,4012335838&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss0.bdstatic.com/70cFvHSh_Q1YnxGkpoWK1HF6hhy/it/u=3781123768,373023027&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss0.bdstatic.com/70cFuHSh_Q1YnxGkpoWK1HF6hhy/it/u=4052445718,1344904722&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss3.bdstatic.com/70cFv8Sh_Q1YnxGkpoWK1HF6hhy/it/u=1730874133,3861130981&fm=27&gp=0.jpg"));
        list.add(new HeaderBean("2016年12月03日"));

        list.add(new ContentBean("https://ss2.bdstatic.com/70cFvnSh_Q1YnxGkpoWK1HF6hhy/it/u=4117837678,3129898700&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=1960816299,803825902&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=3790810349,4012335838&fm=27&gp=0.jpg"));
        list.add(new HeaderBean("2016年12月04日"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=1960816299,803825902&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=3790810349,4012335838&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss0.bdstatic.com/70cFvHSh_Q1YnxGkpoWK1HF6hhy/it/u=3781123768,373023027&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss0.bdstatic.com/70cFuHSh_Q1YnxGkpoWK1HF6hhy/it/u=4052445718,1344904722&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss3.bdstatic.com/70cFv8Sh_Q1YnxGkpoWK1HF6hhy/it/u=1730874133,3861130981&fm=27&gp=0.jpg"));
        list.add(new HeaderBean("2016年12月05日"));
        list.add(new ContentBean("https://ss2.bdstatic.com/70cFvnSh_Q1YnxGkpoWK1HF6hhy/it/u=4117837678,3129898700&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=3790810349,4012335838&fm=27&gp=0.jpg"));
//		list.add("2016-07-24");
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=3790810349,4012335838&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=1960816299,803825902&fm=27&gp=0.jpg"));
        list.add(new HeaderBean("2016年12月06日"));

        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=3790810349,4012335838&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss0.bdstatic.com/70cFvHSh_Q1YnxGkpoWK1HF6hhy/it/u=3781123768,373023027&fm=27&gp=0.jpg"));
//		list.add("2016-07-25");
        list.add(new ContentBean("https://ss0.bdstatic.com/70cFuHSh_Q1YnxGkpoWK1HF6hhy/it/u=4052445718,1344904722&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss3.bdstatic.com/70cFv8Sh_Q1YnxGkpoWK1HF6hhy/it/u=1730874133,3861130981&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss2.bdstatic.com/70cFvnSh_Q1YnxGkpoWK1HF6hhy/it/u=4117837678,3129898700&fm=27&gp=0.jpg"));
        list.add(new HeaderBean("2016年12月07日"));

        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=3790810349,4012335838&fm=27&gp=0.jpg"));
//		list.add("2016-07-26");
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=3790810349,4012335838&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=1960816299,803825902&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=3790810349,4012335838&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss0.bdstatic.com/70cFvHSh_Q1YnxGkpoWK1HF6hhy/it/u=3781123768,373023027&fm=27&gp=0.jpg"));
//		list.add("2016-07-27");
        list.add(new ContentBean("https://ss0.bdstatic.com/70cFuHSh_Q1YnxGkpoWK1HF6hhy/it/u=4052445718,1344904722&fm=27&gp=0.jpg"));
        list.add(new HeaderBean("2016年12月08日"));

        list.add(new ContentBean("https://ss3.bdstatic.com/70cFv8Sh_Q1YnxGkpoWK1HF6hhy/it/u=1730874133,3861130981&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss2.bdstatic.com/70cFvnSh_Q1YnxGkpoWK1HF6hhy/it/u=4117837678,3129898700&fm=27&gp=0.jpg"));
        list.add(new ContentBean("http://pic.wenwen.soso.com/p/20130907/20130907174128-2028703867.jpg"));
        list.add(new HeaderBean("2016年12月09日"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=3790810349,4012335838&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=1960816299,803825902&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=3790810349,4012335838&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss0.bdstatic.com/70cFvHSh_Q1YnxGkpoWK1HF6hhy/it/u=3781123768,373023027&fm=27&gp=0.jpg"));
//		list.add("2016-07-29");
        list.add(new ContentBean("https://ss0.bdstatic.com/70cFuHSh_Q1YnxGkpoWK1HF6hhy/it/u=4052445718,1344904722&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss3.bdstatic.com/70cFv8Sh_Q1YnxGkpoWK1HF6hhy/it/u=1730874133,3861130981&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss2.bdstatic.com/70cFvnSh_Q1YnxGkpoWK1HF6hhy/it/u=4117837678,3129898700&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=3790810349,4012335838&fm=27&gp=0.jpg"));
//		list.add("2016-07-30");
        list.add(new ContentBean("https://ss3.bdstatic.com/70cFv8Sh_Q1YnxGkpoWK1HF6hhy/it/u=1730874133,3861130981&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=1960816299,803825902&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=3790810349,4012335838&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss0.bdstatic.com/70cFvHSh_Q1YnxGkpoWK1HF6hhy/it/u=3781123768,373023027&fm=27&gp=0.jpg"));
        list.add(new HeaderBean("2016年12月10日"));
        list.add(new ContentBean("https://ss0.bdstatic.com/70cFuHSh_Q1YnxGkpoWK1HF6hhy/it/u=4052445718,1344904722&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss3.bdstatic.com/70cFv8Sh_Q1YnxGkpoWK1HF6hhy/it/u=1730874133,3861130981&fm=27&gp=0.jpg"));
        list.add(new ContentBean("https://ss2.bdstatic.com/70cFvnSh_Q1YnxGkpoWK1HF6hhy/it/u=4117837678,3129898700&fm=27&gp=0.jpg"));
        list.add(new HeaderBean("2016年12月11日"));
        list.add(new ContentBean("https://ss1.bdstatic.com/70cFvXSh_Q1YnxGkpoWK1HF6hhy/it/u=1960816299,803825902&fm=27&gp=0.jpg"));

        return list;
    }

    private List<ContentBean> obtainData2() {
        List<ContentBean> list = new ArrayList<>();
        list.add(new ContentBean("2016年12月11日", ""));
        list.add(new ContentBean("2016年12月11日", ""));
        list.add(new ContentBean("2016年12月11日", ""));
        list.add(new ContentBean("2016年12月12日", ""));
        list.add(new ContentBean("2016年12月12日", ""));
        list.add(new ContentBean("2016年12月12日", ""));
        list.add(new ContentBean("2016年12月13日", ""));
        list.add(new ContentBean("2016年12月13日", ""));
        list.add(new ContentBean("2016年12月13日", ""));
        list.add(new ContentBean("2016年12月13日", ""));
        list.add(new ContentBean("2016年12月14日", ""));
        list.add(new ContentBean("2016年12月14日", ""));
        list.add(new ContentBean("2016年12月14日", ""));
        list.add(new ContentBean("2016年12月15日", ""));
        list.add(new ContentBean("2016年12月15日", ""));
        list.add(new ContentBean("2016年12月16日", ""));
        list.add(new ContentBean("2016年12月17日", ""));
        list.add(new ContentBean("2016年12月17日", ""));
        list.add(new ContentBean("2016年12月17日", ""));
        list.add(new ContentBean("2016年12月17日", ""));
        list.add(new ContentBean("2016年12月18日", ""));
        list.add(new ContentBean("2016年12月18日", ""));
        list.add(new ContentBean("2016年12月18日", ""));
        list.add(new ContentBean("2016年12月19日", ""));
        list.add(new ContentBean("2016年12月19日", ""));
        list.add(new ContentBean("2016年12月19日", ""));
        list.add(new ContentBean("2016年12月20日", ""));
        list.add(new ContentBean("2016年12月20日", ""));
        list.add(new ContentBean("2016年12月20日", ""));
        list.add(new ContentBean("2016年12月21日", ""));
        list.add(new ContentBean("2016年12月21日", ""));
        list.add(new ContentBean("2016年12月21日", ""));
        list.add(new ContentBean("2016年12月22日", ""));
        list.add(new ContentBean("2016年12月22日", ""));
        list.add(new ContentBean("2016年12月23日", ""));
        list.add(new ContentBean("2016年12月24日", ""));
        list.add(new ContentBean("2016年12月24日", ""));
        list.add(new ContentBean("2016年12月25日", ""));
        return list;
    }

    private Handler handler = new Handler();
    //写在 onCreate() 的外面
    Runnable runnable = new Runnable() {
        @Override
        public void run() {
            /**
             逻辑代码写在这
             **/
            mDataList.add(new ContentBean("2016年12月10日", ""));
            List list = SortDataHelper.sortData(mDataList);
            mAdapter.setDataList(list);
            //这个好像才是执行周期的时间（单位：ms）
            handler.postDelayed(this, 3000);
        }
    };

    @Override
    protected void onDestroy() {
        super.onDestroy();
        handler.removeCallbacks(runnable);
    }
}
