package com.cneeds.notouch.operation;

import android.view.KeyEvent;

import com.cneeds.notouch.NoTouchConstant;
import com.cneeds.notouch.NoTouchFocusController;
import com.cneeds.notouch.NoTouchLog;
import com.cneeds.notouch.NoTouchParam;
import com.cneeds.notouch.bean.ActivityOperationBean;
import com.cneeds.notouch.bean.CoordinateBean;
import com.cneeds.notouch.bean.OperationBean;

import static com.cneeds.notouch.NoTouchConstant.CoordinateLevel.LEVEL_0;
import static com.cneeds.notouch.NoTouchConstant.CoordinateLevel.LEVEL_1;
import static com.cneeds.notouch.NoTouchConstant.MAX_VALUE;
import static com.cneeds.notouch.NoTouchConstant.OperationFlag.OPERATION_NO_FOCUS;
import static com.cneeds.notouch.NoTouchConstant.OperationFlag.OPERATION_SELECTED;
import static com.cneeds.notouch.NoTouchConstant.OperationResult.LOADING;
import static com.cneeds.notouch.NoTouchConstant.OperationResult.SAME;
import static com.cneeds.notouch.NoTouchConstant.OperationResult.SUCCESS;

public abstract class AbsNoTouchOperation implements NoTouchOperation{

    protected NoTouchFocusController.ActivityOperationListener mOperationListener;
    private CoordinateBean mCoordinateBean;
    private int mFailCount = 0;
    private NoTouchParam mNoTouchParam;

    protected AbsNoTouchOperation(NoTouchParam param){
        mNoTouchParam = param;
    }

    protected NoTouchParam getNoTouchParam(){
        return mNoTouchParam;
    }

    @Override
    public void registerActivityOperationResult(NoTouchFocusController.ActivityOperationListener operationListener) {
        mOperationListener = operationListener;
    }

    @Override
    public void operation(int keyCode, KeyEvent keyEvent) {
        NoTouchLog.d("keyCode = " + keyCode);
        if(mOperationListener == null){
            try {
                throw new Exception("registerActivityOperationResult no call");
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        while(true){
            OperationBean operationBean;
            if(mCoordinateBean == null){
                operationBean = getInitOperationBean();
                if(mNoTouchParam.getInitCoordinateBean() != null){
                    operationBean.setCoordinateBean(mNoTouchParam.getInitCoordinateBean().copyCoordinate());
                }
            }else{
                if(keyCode == NoTouchConstant.INIT_KEY_CODE){
                    return;
                }
                operationBean = operationReal(keyCode, keyEvent);
            }
            NoTouchLog.d("operationBean OperationFlag = " + operationBean.getOperationFlag());

            if(operationBean.getOperationFlag() == OPERATION_NO_FOCUS
                    && mNoTouchParam.getNoNavigationBar()){
                mFailCount = 0;
                break;
            }

            ActivityOperationBean activityOperationBean = mOperationListener.activityOperation(operationBean);
            NoTouchLog.d("activityOperationBean result = " + activityOperationBean.getOperationResult());
            if(activityOperationBean.getOperationResult() == LOADING){
                mFailCount = 0;
                break;
            }


            if(activityOperationBean.getOperationResult() == SAME){
                if(activityOperationBean.getCoordinateBean() != null
                        && existMaxValue(operationBean.getCoordinateBean())){
                    mCoordinateBean.copyCoordinate(activityOperationBean.getCoordinateBean());
                    continue;
                }
                if(mCoordinateBean == null){
                    mCoordinateBean = operationBean.getCoordinateBean().copyCoordinate();
                }else{
                    mCoordinateBean.copyCoordinate(operationBean.getCoordinateBean());
                }
                continue;
            }
            if(activityOperationBean.getOperationResult() == SUCCESS){

                if(operationBean.getOperationFlag() == OPERATION_NO_FOCUS){
                    mFailCount = 0;
                    break;
                }

                if(operationBean.getOperationFlag() != OPERATION_SELECTED){
                    mFailCount = 0;
                    break;
                }

                if(mCoordinateBean == null){
                    mCoordinateBean = operationBean.getCoordinateBean().copyCoordinate();
                }else{
                    mCoordinateBean.copyCoordinate(operationBean.getCoordinateBean());
                }

                if(activityOperationBean.getCoordinateBean() != null
                        && existMaxValue(operationBean.getCoordinateBean())){
                    mCoordinateBean.copyCoordinate(activityOperationBean.getCoordinateBean());
                }
                mFailCount = 0;
                break;
            }
            mFailCount = mFailCount + 1;
        }
    }

    protected final CoordinateBean getCoordinateBean(){
        return mCoordinateBean;
    }

    protected final int getCoordinateLevel(CoordinateBean coordinateBean){
        if(coordinateBean.getX() >= 1 && coordinateBean.getY() >= 1){
            return LEVEL_0;
        }

        return LEVEL_1;
    }

    protected int getFailCount(){
        return mFailCount;
    }

    protected boolean existMaxValue(CoordinateBean coordinateBean){
        if(coordinateBean.getYy() == MAX_VALUE
                || coordinateBean.getXx() == MAX_VALUE
                || coordinateBean.getX() == MAX_VALUE
                || coordinateBean.getY() == MAX_VALUE){
            return true;
        }
        return false;
    }

    @Override
    public void restoreLastCoordinate() {
        if(mCoordinateBean != null){
            OperationBean operationBean = new OperationBean();
            operationBean.setOperationFlag(OPERATION_SELECTED);
            operationBean.setCoordinateBean(mCoordinateBean.copyCoordinate());
            mOperationListener.activityOperation(operationBean);
        }else{
            operation(NoTouchConstant.INIT_KEY_CODE, null);
        }
    }

    @Override
    public void resetInitCoordinate() {
        if(mCoordinateBean != null){
            mCoordinateBean = getInitOperationBean().getCoordinateBean().copyCoordinate();
        }
    }

    @Override
    public void setLastCoordinate(CoordinateBean coordinate) {
        if(mCoordinateBean != null){
            mCoordinateBean.copyCoordinate(coordinate);
        }
    }

    public abstract OperationBean operationReal(int keyCode, KeyEvent keyEvent);

    public abstract OperationBean getInitOperationBean();

}
