package com.cneeds.notouch.operation;

import android.view.KeyEvent;

import com.cneeds.notouch.NoTouchConstant;
import com.cneeds.notouch.NoTouchFocusController;
import com.cneeds.notouch.NoTouchParam;
import com.cneeds.notouch.bean.CoordinateBean;
import com.cneeds.notouch.bean.OperationBean;

import static com.cneeds.notouch.NoTouchConstant.CoordinateLevel.LEVEL_0;
import static com.cneeds.notouch.NoTouchConstant.MAX_VALUE;
import static com.cneeds.notouch.NoTouchConstant.OperationConstant.MIN_VALID_VALUE;
import static com.cneeds.notouch.NoTouchConstant.OperationConstant.NONE_VALUE;
import static com.cneeds.notouch.NoTouchConstant.OperationFlag.OPERATION_ENTER;
import static com.cneeds.notouch.NoTouchConstant.OperationFlag.OPERATION_NONE;
import static com.cneeds.notouch.NoTouchConstant.OperationFlag.OPERATION_NO_FOCUS;
import static com.cneeds.notouch.NoTouchConstant.OperationFlag.OPERATION_SELECTED;
import static com.cneeds.notouch.NoTouchConstant.OperationFlag.OPERATION_SELECTED;

public class DoubleLevelVerticalOperation extends AbsNoTouchOperation{



    private int LEVEL_0_MIN_VALUE = 1;
    private int LEVEL_1_MIN_VALUE = 0;

    protected DoubleLevelVerticalOperation(NoTouchParam param) {
        super(param);
    }


    @Override
    public OperationBean operationReal(int keyCode, KeyEvent keyEvent) {
        OperationBean operationBean = new OperationBean();
        operationBean.setCoordinateBean(getCoordinateBean().copyCoordinate());
        switch (keyCode){
            case KeyEvent.KEYCODE_DPAD_LEFT:
                leftKeyEvent(operationBean);
                break;
            case KeyEvent.KEYCODE_DPAD_UP:
                upKeyEvent(operationBean);
                break;
            case KeyEvent.KEYCODE_DPAD_RIGHT:
                rightKeyEvent(operationBean);
                break;
            case KeyEvent.KEYCODE_DPAD_DOWN:
                downKeyEvent(operationBean);
                break;
            case KeyEvent.KEYCODE_SOFT_LEFT:
                shiftLeftKeyEvent(operationBean);
                break;
            case KeyEvent.KEYCODE_SOFT_RIGHT:
                shiftRightKeyEvent(operationBean);
                break;
            case KeyEvent.KEYCODE_ENTER:
                enterKeyEvent(operationBean);
                break;
            default:
                break;
        }
        return operationBean;
    }

    @Override
    public OperationBean getInitOperationBean() {
        OperationBean operationBean = new OperationBean();
        CoordinateBean coordinateBean = new CoordinateBean();
        coordinateBean.setX(LEVEL_1_MIN_VALUE);
        coordinateBean.setY(LEVEL_1_MIN_VALUE);
        operationBean.setCoordinateBean(coordinateBean);
        operationBean.setOperationFlag(OPERATION_SELECTED);
        return operationBean;
    }

    private void shiftRightKeyEvent(OperationBean operationBean) {
        if(getCoordinateLevel(operationBean.getCoordinateBean()) == LEVEL_0){
            switch (getFailCount()){
                case NoTouchConstant.OperationFailCount.FAIL_NONE:{
                    operationBean.getCoordinateBean().setX(operationBean.getCoordinateBean().getX() + 1);
                    operationBean.setOperationFlag(OPERATION_SELECTED);
                }
                    break;
                case NoTouchConstant.OperationFailCount.FAIL_ONE:{
                    operationBean.getCoordinateBean().setX(LEVEL_0_MIN_VALUE);
                    operationBean.getCoordinateBean().setY(operationBean.getCoordinateBean().getY() + 1);
                    operationBean.setOperationFlag(OPERATION_SELECTED);
                }
                    break;
                case NoTouchConstant.OperationFailCount.FAIL_TWO:{
                    operationBean.getCoordinateBean().setX(LEVEL_1_MIN_VALUE);
                    operationBean.getCoordinateBean().setY(LEVEL_1_MIN_VALUE);
                    operationBean.getCoordinateBean().setXx(operationBean.getCoordinateBean().getXx() + 1);
                    operationBean.setOperationFlag(OPERATION_SELECTED);
                }
                    break;
                case NoTouchConstant.OperationFailCount.FAIL_THIRD:{
                    operationBean.getCoordinateBean().setX(LEVEL_1_MIN_VALUE);
                    operationBean.getCoordinateBean().setY(LEVEL_1_MIN_VALUE);
                    operationBean.getCoordinateBean().setYy(operationBean.getCoordinateBean().getYy() + 1);
                    operationBean.setOperationFlag(OPERATION_SELECTED);
                }
                    break;
                case NoTouchConstant.OperationFailCount.FAIL_FOUR:{
                    operationBean.setOperationFlag(OPERATION_NONE);
                }
                    break;
                default:
                    break;
            }
        }else{
            switch (getFailCount()){
                case NoTouchConstant.OperationFailCount.FAIL_NONE:{
                    operationBean.getCoordinateBean().setXx(operationBean.getCoordinateBean().getXx() + 1);
                    operationBean.setOperationFlag(OPERATION_SELECTED);
                }
                    break;
                case NoTouchConstant.OperationFailCount.FAIL_ONE:{
                    operationBean.getCoordinateBean().setYy(operationBean.getCoordinateBean().getYy() + 1);
                    operationBean.setOperationFlag(OPERATION_SELECTED);
                }
                    break;
                case NoTouchConstant.OperationFailCount.FAIL_TWO:{
                    operationBean.setOperationFlag(OPERATION_NONE);
                }
                    break;
                default:
                    break;
            }
        }
    }

    private void shiftLeftKeyEvent(OperationBean operationBean) {
        if(getCoordinateLevel(operationBean.getCoordinateBean()) == LEVEL_0){
            switch (getFailCount()){
                case NoTouchConstant.OperationFailCount.FAIL_NONE:{
                    if(operationBean.getCoordinateBean().getX() > LEVEL_0_MIN_VALUE){
                        operationBean.getCoordinateBean().setX(operationBean.getCoordinateBean().getX() - 1);
                        operationBean.setOperationFlag(OPERATION_SELECTED);
                    }else if(operationBean.getCoordinateBean().getY() > LEVEL_0_MIN_VALUE){
                        operationBean.getCoordinateBean().setX(MAX_VALUE);
                        operationBean.getCoordinateBean().setY(operationBean.getCoordinateBean().getY() - 1);
                        operationBean.setOperationFlag(OPERATION_SELECTED);
                    }else{
                        operationBean.getCoordinateBean().setX(LEVEL_1_MIN_VALUE);
                        operationBean.getCoordinateBean().setY(LEVEL_1_MIN_VALUE);
                        operationBean.setOperationFlag(OPERATION_SELECTED);
                    }
                }
                    break;
                default:
                    break;
            }
        }else{
            if(operationBean.getCoordinateBean().getXx() > LEVEL_1_MIN_VALUE){
                operationBean.getCoordinateBean().setXx(operationBean.getCoordinateBean().getXx() - 1);
                operationBean.setOperationFlag(OPERATION_SELECTED);
            }else if(operationBean.getCoordinateBean().getYy() > LEVEL_1_MIN_VALUE){
                operationBean.getCoordinateBean().setYy(operationBean.getCoordinateBean().getYy() - 1);
                operationBean.setOperationFlag(OPERATION_SELECTED);
            }else{
                operationBean.setOperationFlag(OPERATION_NO_FOCUS);
            }
        }
    }

    private void enterKeyEvent(OperationBean operationBean) {
        if(getFailCount() == 1){
            operationBean.setOperationFlag(OPERATION_NONE);
            return;
        }
        if(getCoordinateLevel(operationBean.getCoordinateBean()) == LEVEL_0){
            operationBean.setOperationFlag(OPERATION_ENTER);
        }else{
            operationBean.getCoordinateBean().setX(LEVEL_0_MIN_VALUE);
            operationBean.getCoordinateBean().setY(LEVEL_0_MIN_VALUE);
            operationBean.setOperationFlag(OPERATION_SELECTED);
        }
    }

    private void downKeyEvent(OperationBean operationBean) {
        if(getFailCount() == 1){
            operationBean.setOperationFlag(OPERATION_NONE);
            return;
        }
        if(getCoordinateLevel(operationBean.getCoordinateBean()) == LEVEL_0){
            operationBean.getCoordinateBean().setY(operationBean.getCoordinateBean().getY() + 1);
            operationBean.setOperationFlag(OPERATION_SELECTED);
        }else{
            operationBean.getCoordinateBean().setYy(operationBean.getCoordinateBean().getYy() + 1);
            operationBean.setOperationFlag(OPERATION_SELECTED);
        }
    }

    private void rightKeyEvent(OperationBean operationBean) {
        if(getFailCount() == 1){
            operationBean.setOperationFlag(OPERATION_NONE);
            return;
        }
        if(getCoordinateLevel(operationBean.getCoordinateBean()) == LEVEL_0){
            operationBean.getCoordinateBean().setX(operationBean.getCoordinateBean().getX() + 1);
            operationBean.setOperationFlag(OPERATION_SELECTED);
        }else{
            operationBean.getCoordinateBean().setX(LEVEL_0_MIN_VALUE);
            operationBean.getCoordinateBean().setY(LEVEL_0_MIN_VALUE);
            operationBean.setOperationFlag(OPERATION_SELECTED);
        }
    }

    private void upKeyEvent(OperationBean operationBean) {
        if(getFailCount() == 1){
            operationBean.setOperationFlag(OPERATION_NONE);
            return;
        }
        if(getCoordinateLevel(operationBean.getCoordinateBean()) == LEVEL_0){
            if(operationBean.getCoordinateBean().getY() > LEVEL_0_MIN_VALUE){
                operationBean.getCoordinateBean().setY(operationBean.getCoordinateBean().getY() - 1);
                operationBean.setOperationFlag(OPERATION_SELECTED);
            }else{
                operationBean.setOperationFlag(OPERATION_NONE);
            }
        }else{
            if(operationBean.getCoordinateBean().getYy() > LEVEL_1_MIN_VALUE){
                operationBean.getCoordinateBean().setYy(operationBean.getCoordinateBean().getYy() - 1);
                operationBean.setOperationFlag(OPERATION_SELECTED);
            }else{
                operationBean.setOperationFlag(OPERATION_NONE);
            }
        }
    }

    private void leftKeyEvent(OperationBean operationBean) {
        if(getFailCount() == 1){
            operationBean.setOperationFlag(OPERATION_NONE);
            return;
        }
        if(getCoordinateLevel(operationBean.getCoordinateBean()) == LEVEL_0){
            if(operationBean.getCoordinateBean().getX() > LEVEL_0_MIN_VALUE){
                operationBean.getCoordinateBean().setX(operationBean.getCoordinateBean().getX() - 1);
                operationBean.setOperationFlag(OPERATION_SELECTED);
            }else{
                operationBean.getCoordinateBean().setX(LEVEL_1_MIN_VALUE);
                operationBean.getCoordinateBean().setY(LEVEL_1_MIN_VALUE);
                operationBean.setOperationFlag(OPERATION_SELECTED);
            }
        }else{
            operationBean.setOperationFlag(OPERATION_NO_FOCUS);
        }
    }
}
