package com.cneeds.notouch.operation;

import android.view.KeyEvent;

import com.cneeds.notouch.NoTouchParam;
import com.cneeds.notouch.bean.CoordinateBean;
import com.cneeds.notouch.bean.OperationBean;

import static com.cneeds.notouch.NoTouchConstant.MAX_VALUE;
import static com.cneeds.notouch.NoTouchConstant.OperationFailCount.FAIL_NONE;
import static com.cneeds.notouch.NoTouchConstant.OperationFailCount.FAIL_ONE;
import static com.cneeds.notouch.NoTouchConstant.OperationFailCount.FAIL_TWO;
import static com.cneeds.notouch.NoTouchConstant.OperationFlag.OPERATION_ENTER;
import static com.cneeds.notouch.NoTouchConstant.OperationFlag.OPERATION_NONE;
import static com.cneeds.notouch.NoTouchConstant.OperationFlag.OPERATION_SELECTED;

/**
 * 描述：新增单层operation，这种类型在第一个时，再左旋不会主动把focus交还给SystemUI，
 * 在最后一个再右旋，还会通过OPERATION_SELECTED返回，
 * 由应用自己处理，用于展开多个fragment的情况
 * Created by LeoHo on 2020/3/19.
 */

public class SingleLevelOperation2 extends AbsNoTouchOperation {


    private int LEVEL_0_MIN_VALUE = 0;

    protected SingleLevelOperation2(NoTouchParam param) {
        super(param);
    }


    @Override
    public OperationBean operationReal(int keyCode, KeyEvent keyEvent) {
        OperationBean operationBean = new OperationBean();
        operationBean.setCoordinateBean(getCoordinateBean().copyCoordinate());
        switch (keyCode) {
            case KeyEvent.KEYCODE_DPAD_LEFT:
                leftKeyEvent(operationBean);
                break;
            case KeyEvent.KEYCODE_DPAD_UP:
                upKeyEvent(operationBean);
                break;
            case KeyEvent.KEYCODE_DPAD_RIGHT:
                rightKeyEvent(operationBean);
                break;
            case KeyEvent.KEYCODE_DPAD_DOWN:
                downKeyEvent(operationBean);
                break;
            case KeyEvent.KEYCODE_SOFT_LEFT:
                shiftLeftKeyEvent(operationBean);
                break;
            case KeyEvent.KEYCODE_SOFT_RIGHT:
                shiftRightKeyEvent(operationBean);
                break;
            case KeyEvent.KEYCODE_ENTER:
                enterKeyEvent(operationBean);
                break;
            default:
                break;
        }
        return operationBean;
    }

    @Override
    public OperationBean getInitOperationBean() {
        OperationBean operationBean = new OperationBean();
        CoordinateBean coordinateBean = new CoordinateBean();
        operationBean.setCoordinateBean(coordinateBean);
        operationBean.setOperationFlag(OPERATION_SELECTED);
        return operationBean;
    }

    private void shiftRightKeyEvent(OperationBean operationBean) {
        switch (getFailCount()) {
            case FAIL_NONE: {
                operationBean.getCoordinateBean().setX(operationBean.getCoordinateBean().getX() + 1);
                operationBean.setOperationFlag(OPERATION_SELECTED);
            }
            break;
            case FAIL_ONE: {
                operationBean.getCoordinateBean().setX(LEVEL_0_MIN_VALUE);
                operationBean.getCoordinateBean().setY(operationBean.getCoordinateBean().getY() + 1);
                operationBean.setOperationFlag(OPERATION_SELECTED);
            }
            break;
            case FAIL_TWO: {
                operationBean.getCoordinateBean().setX(MAX_VALUE);
                operationBean.getCoordinateBean().setY(MAX_VALUE);
                operationBean.setOperationFlag(OPERATION_SELECTED);
            }
            break;
            default:
                break;
        }
    }

    private void shiftLeftKeyEvent(OperationBean operationBean) {
        if (operationBean.getCoordinateBean().getX() > LEVEL_0_MIN_VALUE) {
            operationBean.getCoordinateBean().setX(operationBean.getCoordinateBean().getX() - 1);
            operationBean.setOperationFlag(OPERATION_SELECTED);
        } else if (operationBean.getCoordinateBean().getY() > LEVEL_0_MIN_VALUE) {
            operationBean.getCoordinateBean().setY(operationBean.getCoordinateBean().getY() - 1);
            operationBean.setOperationFlag(OPERATION_SELECTED);
        } else {
            if (FAIL_NONE == getFailCount()) {
                operationBean.getCoordinateBean().setX(MAX_VALUE);
            } else {
                operationBean.getCoordinateBean().setY(MAX_VALUE);
            }
            operationBean.setOperationFlag(OPERATION_SELECTED);
        }
    }

    private void enterKeyEvent(OperationBean operationBean) {
        if (getFailCount() == 1) {
            operationBean.setOperationFlag(OPERATION_NONE);
            return;
        }
        operationBean.setOperationFlag(OPERATION_ENTER);
    }

    private void downKeyEvent(OperationBean operationBean) {
        switch (getFailCount()) {
            case FAIL_NONE: {
                operationBean.getCoordinateBean().setY(operationBean.getCoordinateBean().getY() + 1);
                operationBean.setOperationFlag(OPERATION_SELECTED);
            }
            break;
            case FAIL_ONE: {
                operationBean.setOperationFlag(OPERATION_NONE);
            }
            break;
            default:
                break;
        }
    }

    private void rightKeyEvent(OperationBean operationBean) {
        switch (getFailCount()) {
            case FAIL_NONE: {
                operationBean.getCoordinateBean().setX(operationBean.getCoordinateBean().getX() + 1);
                operationBean.setOperationFlag(OPERATION_SELECTED);
            }
            break;
            case FAIL_ONE: {
                operationBean.setOperationFlag(OPERATION_NONE);
            }
            break;
            default:
                break;
        }
    }

    private void upKeyEvent(OperationBean operationBean) {
        if (operationBean.getCoordinateBean().getY() > LEVEL_0_MIN_VALUE) {
            operationBean.getCoordinateBean().setY(operationBean.getCoordinateBean().getY() - 1);
            operationBean.setOperationFlag(OPERATION_SELECTED);
        } else {
            operationBean.setOperationFlag(OPERATION_NONE);
        }
    }

    private void leftKeyEvent(OperationBean operationBean) {
        if (operationBean.getCoordinateBean().getX() > LEVEL_0_MIN_VALUE) {
            operationBean.getCoordinateBean().setX(operationBean.getCoordinateBean().getX() - 1);
            operationBean.setOperationFlag(OPERATION_SELECTED);
        } else {
            operationBean.getCoordinateBean().setX(MAX_VALUE);
            operationBean.setOperationFlag(OPERATION_SELECTED);
        }
    }
}
