# 快捷使用
## 第一步：初始化显示数据，区分标题Item和普通Item
```
List<Object> dataList = new ArrayList<>();  
dataList.add(new HeaderBean("标题"));   
dataList.add(new ContentBean("图片路径")); 
```


## 第二步：给recyclerview添加LayoutManager和adapter,如下：
```
        mLayoutManager = new CenterGridLayoutManager(context, SPAN_COUNT, dataList);
        recyclerView.setLayoutManager(mLayoutManager);
        mAdapter = new GridRecyclerAdapter<>(dataList, SPAN_COUNT);
        recyclerView.setAdapter(mAdapter);
```

如果要粘性头效果还得添加：
```
        recyclerView.addItemDecoration(new PinnedHeaderItemDecoration());
```


## 第三步：删除按钮处理 和 全选状态回调

在你的删除按钮的点击监听里调用：
```
 mAdapter.deleteSelected()
```

全选状态监听：
```
        mAdapter.setOnSelectListener(new GridRecyclerAdapter.OnSelectListener() {
            @Override
            public void onSelect(View v, int position, int selectedItemCount, int contentItemCount) {
                if (mTvSelectAll != null && mTvSelectAll.getVisibility() == View.VISIBLE) {
                    if (selectedItemCount != contentItemCount) {
                        if ("全不选".equals(mTvSelectAll.getText())) {
                            mTvSelectAll.setText("全选");
                        }
                    } else {
                        if ("全选".equals(mTvSelectAll.getText())) {
                            mTvSelectAll.setText("全不选");
                        }
                    }
                }
            }
        });
    }
```


## 第四步：旋钮事件处理,
这个最麻烦，可以参考现有demo
### 4.1
```
   public ActivityOperationBean onSelectedChange(CoordinateBean coordinateBean) {
        ActivityOperationBean activityOperationBean = new ActivityOperationBean();
        int x = coordinateBean.getX();
            if (mAdapter != null) {
               // 1. 获取到移动到下一个位置的adapter position
                KeyEventHelper.PositionBean positionBean = mAdapter.moveToNext(coordinateBean.getX(), coordinateBean.getY());
                coordinateBean.setY(positionBean.getY() + 1);
                coordinateBean.setX(positionBean.getX());
                int adapterPosition = positionBean.getAdapterPosition();
                if (adapterPosition >= 0) {
                    // 2. 设置recyclerView滚动居中
                    mRvGrid.smoothScrollToPosition(adapterPosition);
                    activityOperationBean.setOperationResult(NoTouchConstant.OperationResult.SUCCESS);
                } else {
                    activityOperationBean.setOperationResult(NoTouchConstant.OperationResult.FAIL);
                }
            }
        return activityOperationBean;
    }
```

### 4.2
当焦点移出recyclerView区域时，需要调用，调用时机需要结合嵌入的界面：
```
 mAdapter.setCurrentHighLight(GridRecyclerAdapter.NONE_SELECT);
```
可以用下面方法获取当前高亮的Item的Adapter的position，如果当前没有高亮位置返回GridRecyclerAdapter.NONE_SELECT
```
mAdapter.getCurrentHighLightPosition()
```
例子：一般会在onSelectNone调用
```
    @Override
    public ActivityOperationBean onSelectNone() {
        if (mAdapter != null && mAdapter.getCurrentHighLightPosition() != GridRecyclerAdapter.NONE_SELECT) {
            mAdapter.setCurrentHighLight(GridRecyclerAdapter.NONE_SELECT);
        }
    }
```



# 如果需要自定义，步骤如下：

## 第一步：标题类继承IHeader,区分标题Item和普通Item
```
public class 你的标题数据类 implements IHeader {  
          // do something ....  
} 
```

## 第二步：继承BaseViewHolder,绑定你自定义的view和数据
```
1.public class 你的标题Holder类名 extends BaseViewHolder<你的标题数据类> {  
2.  
3.    public 你的标题Holder类名(Context context, ViewGroup root) {  
4.        super(context, root, 你的标题Item布局文件ID);  
5.        // do something ... e.g. findViewById  
6.    }  
7.  
8.    @Override  
9.    public void bindData(你的标题数据类 s, int position,   
10.                                 GridRecyclerAdapter adapter) {  
11.        // 绑定数据到View  
12.    }  
} 
```
```
1.public class 你的内容Holder类名 extends BaseViewHolder<你的内容数据类> {  
2.  
3.    public 你的内容Holder类名(Context context, ViewGroup root) {  
4.        super(context, root, 你的内容Item布局文件ID);  
5.        // do something ... e.g. findViewById  
6.    }  
7.  
8.    @Override  
9.    public void bindData(你的内容数据类 s, int position,   
10.                                 GridRecyclerAdapter adapter) {  
11.        // 绑定数据到View  
12.    }  
} 
```


## 第三步：继承GridRecyclerAdapter,重写onCreateViewHolder
```
public class CustomerAdapter extends GridRecyclerAdapter {
    /**
     * @param dataList
     * @param spanCount The number of columns in the grid
     */
    public CustomerAdapter(List dataList, int spanCount) {
        super(dataList, spanCount);
    }

    @Override
    public BaseViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        if (viewType == VIEW_TYPE_ITEM_HEADER) {
            // 这里返回你的标题ViewHolder
        } else{
            // 这里返回你的内容ViewHolder
        }
    }
}
```

# 一些Adapter提供的数据
当前是否处于编辑模式：
```
adapter.getEditMode(); // true: 处于，false,不处于
```

在编辑模式中，判断当前item是否被选择（一般用于自定义ViewHolder）
```
boolean selected = adapter.isSelected(position);
```
在编辑模式中，通知adapter当前item选择状态被更改（一般用于自定义ViewHolder）
```
adapter.toggleSelection(v, finalPosition);
```

在旋钮事件响应时，判断当前item是否需要展示选中状态（一般用于自定义ViewHolder）
```
if (adapter.getCurrentHighLightPosition() == position)

```

