package com.cneeds.rvhelpers.adapter;

import android.support.v7.widget.RecyclerView;
import android.util.SparseBooleanArray;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by mqh on 11/4/16.
 */

public abstract class SelectableAdapter<VH extends RecyclerView.ViewHolder> extends RecyclerView.Adapter<VH> {
    private ArrayList<Object> mSelectedItems;

    public SelectableAdapter() {
        mSelectedItems = new ArrayList<>();
    }


    public boolean isSelected(Object dataBean) {
        return getSelectedItems().contains(dataBean);
    }

    /**
     * Toggle the selection status of the item at a given position
     *
     * @param position Position of the item to toggle the selection status for
     */
    public boolean toggleSelection(int position, Object obj) {
        boolean isChecked;

        if (getSelectedItems().contains(obj)) {
            getSelectedItems().remove(obj);
            isChecked = false;
        } else {
            getSelectedItems().add(obj);
            isChecked = true;
        }
        notifyItemChanged(position);
        return isChecked;
    }

    /**
     * Count the selected items
     *
     * @return Selected items count
     */
    public int getSelectedItemCount() {
        return getSelectedItems().size();
    }

    /**
     * Indicates the list of selected items
     *
     * @return List of selected items ids
     */
    public List getSelectedItems() {
        if (mSelectedItems == null) {
            mSelectedItems = new ArrayList<>();
        }
        return mSelectedItems;
    }

    /**
     * Clear the selection status for all items
     */
    public void clearAllSelection() {
        getSelectedItems().clear();
        notifyDataSetChanged();
    }
}